@@ -1,5 +1,5 @@
 /* server.c --- ANONYMOUS mechanism as defined in RFC 2245, server side.
- * Copyright (C) 2002, 2003, 2004  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -27,33 +27,28 @@
 /* Get specification. */
 #include "anonymous.h"
 
-/* Get malloc, free. */
-#include <stdlib.h>
-
-/* Get memcpy. */
-#include <string.h>
-
 int
 _gsasl_anonymous_server_step (Gsasl_session * sctx,
 			      void *mech_data,
 			      const char *input, size_t input_len,
 			      char **output, size_t * output_len)
 {
-  char *token;
-
   *output = NULL;
   *output_len = 0;
 
-  if (input_len == 0)
+  if (!input)
     return GSASL_NEEDS_MORE;
 
-  token = malloc (input_len + 1);
-  if (token == NULL)
-    return GSASL_MALLOC_ERROR;
-  memcpy (token, input, input_len);
-  token[input_len] = '\0';
-  gsasl_property_set (sctx, GSASL_ANONYMOUS_TOKEN, token);
-  free (token);
+  /* token       = 1*255TCHAR
+     The <token> production is restricted to 255 UTF-8 encoded Unicode
+     characters.   As the encoding of a characters uses a sequence of 1
+     to 4 octets, a token may be long as 1020 octets. */
+  if (input_len == 0 || input_len > 1020)
+    return GSASL_MECHANISM_PARSE_ERROR;
+
+  /* FIXME: Validate that input is UTF-8. */
+
+  gsasl_property_set_raw (sctx, GSASL_ANONYMOUS_TOKEN, input, input_len);
 
   return gsasl_callback (NULL, sctx, GSASL_VALIDATE_ANONYMOUS);
 }
