@@ -67,11 +67,14 @@ _gsasl_ntlm_client_step (Gsasl_session * sctx,
   tSmbNtlmAuthRequest request;
   tSmbNtlmAuthChallenge challenge;
   tSmbNtlmAuthResponse response;
-  /* XXX create callback for domain? Doesn't seem to be needed by servers */
-  char *domain = NULL;
-  const char *password, *authid;
+  const char *domain = gsasl_property_get (sctx, GSASL_REALM);
+  const char *authid = gsasl_property_get (sctx, GSASL_AUTHID);
+  const char *password;
   int res;
 
+  if (!authid)
+    return GSASL_NO_AUTHID;
+
   switch (state->step)
     {
     case 0:
@@ -79,10 +82,6 @@ _gsasl_ntlm_client_step (Gsasl_session * sctx,
          if (input_len != 1 && *input != '+')
          return GSASL_MECHANISM_PARSE_ERROR; */
 
-      authid = gsasl_property_get (sctx, GSASL_AUTHID);
-      if (!authid)
-	return GSASL_NO_AUTHID;
-
       buildSmbNtlmAuthRequest (&request, authid, domain);
 
       *output_len = SmbLength (&request);
@@ -110,10 +109,6 @@ _gsasl_ntlm_client_step (Gsasl_session * sctx,
       if (!password)
 	return GSASL_NO_PASSWORD;
 
-      authid = gsasl_property_get (sctx, GSASL_AUTHID);
-      if (!authid)
-	return GSASL_NO_AUTHID;
-
       buildSmbNtlmAuthResponse (&challenge, &response, authid, password);
 
       *output_len = SmbLength (&response);
