@@ -1,5 +1,5 @@
 /* error.c --- Error handling functionality.
- * Copyright (C) 2002, 2003, 2004  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -51,7 +51,7 @@ gsasl_strerror (int err)
       break;
 
     case GSASL_NEEDS_MORE:
-      p = _("SASL mechanisms needs more data");
+      p = _("SASL mechanism needs more data");
       break;
 
     case GSASL_UNKNOWN_MECHANISM:
@@ -62,14 +62,6 @@ gsasl_strerror (int err)
       p = _("SASL mechanism called too many times");
       break;
 
-    case GSASL_FOPEN_ERROR:
-      p = _("Could not open file in SASL library");
-      break;
-
-    case GSASL_FCLOSE_ERROR:
-      p = _("Could not close file in SASL library");
-      break;
-
     case GSASL_MALLOC_ERROR:
       p = _("Memory allocation error in SASL library");
       break;
@@ -143,7 +135,7 @@ gsasl_strerror (int err)
 	_
 	("GSSAPI error creating a display name denoting the client in "
 	 "gss_display_name() in SASL library.  This is probably because "
-	 "the client suplied bad data.");
+	 "the client supplied bad data.");
       break;
 
     case GSASL_GSSAPI_UNSUPPORTED_PROTECTION_ERROR:
@@ -158,17 +150,13 @@ gsasl_strerror (int err)
       break;
 
     case GSASL_AUTHENTICATION_ERROR:
-      p = _("Error authentication user");
+      p = _("Error authenticating user");
       break;
 
     case GSASL_INTEGRITY_ERROR:
       p = _("Integrity error in application payload");
       break;
 
-    case GSASL_NO_MORE_REALMS:
-      p = _("No more realms available (non-fatal)");
-      break;
-
     case GSASL_NO_CLIENT_CODE:
       p = _("Client-side functionality not available in library "
 	    "(application error)");
@@ -179,10 +167,6 @@ gsasl_strerror (int err)
 	    "(application error)");
       break;
 
-    case GSASL_INVALID_HANDLE:
-      p = _("The provided library handle was invalid (application error)");
-      break;
-
     case GSASL_NO_CALLBACK:
       p = _("No callback specified by caller (application error).");
       break;
@@ -233,7 +217,15 @@ gsasl_strerror (int err)
 
 #ifndef GSASL_NO_OBSOLETE
     case GSASL_TOO_SMALL_BUFFER:
-      p = _("SASL function need larger buffer (internal error)");
+      p = _("SASL function needs larger buffer (internal error)");
+      break;
+
+    case GSASL_FOPEN_ERROR:
+      p = _("Could not open file in SASL library");
+      break;
+
+    case GSASL_FCLOSE_ERROR:
+      p = _("Could not close file in SASL library");
       break;
 
     case GSASL_CANNOT_GET_CTX:
@@ -360,6 +352,14 @@ gsasl_strerror (int err)
     case GSASL_UNICODE_NORMALIZATION_ERROR:
       p = _("Failed to perform Unicode Normalization on string.");
       break;
+
+    case GSASL_NO_MORE_REALMS:
+      p = _("No more realms available (non-fatal)");
+      break;
+
+    case GSASL_INVALID_HANDLE:
+      p = _("The provided library handle was invalid (application error)");
+      break;
 #endif
 
     default:
