@@ -136,8 +136,11 @@ gsasl_property_set_raw (Gsasl_session * sctx, Gsasl_property prop,
       if (data)
 	{
 	  *p = malloc (len + 1);
-	  memcpy (*p, data, len);
-	  (*p)[len] = '\0';
+	  if (*p)
+	    {
+	      memcpy (*p, data, len);
+	      (*p)[len] = '\0';
+	    }
 	}
       else
 	*p = NULL;
@@ -226,6 +229,8 @@ gsasl_property_get (Gsasl_session * sctx, Gsasl_property prop)
       size_t buflen = BUFSIZ - 1;
       int res;
 
+      buf[0] = '\0';
+
       /* Call obsolete callbacks to get properties.  Remove this when
        * the obsolete callbacks are no longer supported. */
 
