@@ -53,9 +53,6 @@ gsasl_step (Gsasl_session * sctx,
 {
   Gsasl_step_function step;
 
-  if (sctx == NULL)
-    return GSASL_INVALID_HANDLE;
-
   if (sctx->clientp)
     step = sctx->mech->client.step;
   else
@@ -106,13 +103,13 @@ gsasl_step64 (Gsasl_session * sctx, const char *b64input, char **b64output)
 
   if (res == GSASL_OK || res == GSASL_NEEDS_MORE)
     {
-      res = gsasl_base64_to (output, output_len, b64output, NULL);
+      int tmpres = gsasl_base64_to (output, output_len, b64output, NULL);
 
       if (output != NULL)
 	free (output);
 
-      if (res != GSASL_OK)
-	return res;
+      if (tmpres != GSASL_OK)
+	return tmpres;
     }
 
   return res;
