@@ -123,12 +123,44 @@ callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
 	      readutf8line ("Enter authentication ID: ");
 	}
 
-      gsasl_property_set (sctx, GSASL_AUTHID, args_info.authentication_id_arg);
+      gsasl_property_set (sctx, GSASL_AUTHID,
+			  args_info.authentication_id_arg);
       rc = GSASL_OK;
       break;
 
     case GSASL_AUTHZID:
-      gsasl_property_set (sctx, GSASL_AUTHZID, args_info.authorization_id_arg);
+      gsasl_property_set (sctx, GSASL_AUTHZID,
+			  args_info.authorization_id_arg);
+      rc = GSASL_OK;
+      break;
+
+    case GSASL_SERVICE:
+      if (args_info.service_arg == NULL)
+	args_info.service_arg =
+	  readutf8line ("Enter GSSAPI service name (e.g. \"imap\"): ");
+
+      gsasl_property_set (sctx, GSASL_SERVICE, args_info.service_arg);
+
+      rc = GSASL_OK;
+      break;
+
+    case GSASL_HOSTNAME:
+      if (args_info.hostname_arg == NULL)
+	args_info.hostname_arg = readutf8line ("Enter hostname of server: ");
+
+      gsasl_property_set (sctx, GSASL_HOSTNAME, args_info.hostname_arg);
+
+      rc = GSASL_OK;
+      break;
+
+    case GSASL_REALM:
+      if (args_info.realm_arg == NULL)
+	args_info.realm_arg =
+	  readutf8line ("Enter realm of server (optional): ");
+
+      if (args_info.realm_arg && *args_info.realm_arg)
+	gsasl_property_set (sctx, GSASL_REALM, args_info.realm_arg);
+
       rc = GSASL_OK;
       break;
 
