@@ -86,7 +86,8 @@ static struct sasltv sasltv[] = {
    {"VXNlciBOYW1l", "YXV0aGlk", "UGFzc3dvcmQ=", "cGFzc3dvcmQ=", NULL,
     NULL}, "password", NULL, "authid"},
   {CLIENT, "LOGIN",
-   {"VXNlciBOYW1l", "YXV0aGlk", "UGFzc3dvcmQ=", "YQ==", NULL, NULL}, "a", NULL,
+   {"VXNlciBOYW1l", "YXV0aGlk", "UGFzc3dvcmQ=", "YQ==", NULL, NULL}, "a",
+   NULL,
    "authid"},
   {CLIENT, "LOGIN",
    {"VXNlciBOYW1l", "YXV0aGlk", "UGFzc3dvcmQ=", "wqo=", NULL, NULL}, UTF8_a,
