@@ -28,7 +28,7 @@
 
 #include "utils.h"
 
-int debug = 0;
+int debug = 1;
 int error_count = 0;
 int break_on_error = 0;
 
@@ -45,6 +45,17 @@ fail (const char *format, ...)
     exit (1);
 }
 
+void
+success (const char *format, ...)
+{
+  va_list arg_ptr;
+
+  va_start (arg_ptr, format);
+  if (debug)
+    vfprintf (stdout, format, arg_ptr);
+  va_end (arg_ptr);
+}
+
 void
 escapeprint (const char *str, size_t len)
 {
